"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const blinkDiff = require("blink-diff");
const image_options_1 = require("./image-options");
class ImageHelper {
    constructor(_args) {
        this._args = _args;
    }
    get cropImageRect() {
        return this._cropImageRect;
    }
    set cropImageRec(rect) {
        this._cropImageRect = rect;
    }
    get blockOutAreas() {
        return this._blockOutAreas;
    }
    set blockOutAreas(rectangles) {
        this._blockOutAreas = rectangles;
    }
    imageOutputLimit() {
        return image_options_1.ImageOptions.outputAll;
    }
    thresholdType() {
        return image_options_1.ImageOptions.pixel;
    }
    threshold() {
        return 0.1; // 0.1 percent; 500 percent
    }
    delta() {
        return 20;
    }
    static getOffsetPixels(args) {
        return args.device.config ? args.device.config.offsetPixels : 0;
    }
    static cropImageDefaultParams(_args) {
        return { x: 0, y: ImageHelper.getOffsetPixels(_args) };
    }
    runDiff(diffOptions, diffImage) {
        return new Promise((resolve, reject) => {
            diffOptions.run(function (error, result) {
                if (error) {
                    throw error;
                }
                else {
                    let message;
                    let resultCode = diffOptions.hasPassed(result.code);
                    if (resultCode) {
                        message = "Screen compare passed!";
                        console.log(message);
                        console.log('Found ' + result.differences + ' differences.');
                        return resolve(true);
                    }
                    else {
                        message = "Screen compare failed!";
                        console.log(message);
                        console.log('Found ' + result.differences + ' differences.');
                        console.log('Diff image: ' + diffImage);
                        return resolve(false);
                    }
                }
            });
        });
    }
    compareImages(actual, expected, output, valueThreshold = this.threshold(), typeThreshold = image_options_1.ImageOptions.pixel) {
        const rectToCrop = this._cropImageRect || ImageHelper.cropImageDefaultParams(this._args);
        let diff = new blinkDiff({
            imageAPath: actual,
            imageBPath: expected,
            imageOutputPath: output,
            imageOutputLimit: this.imageOutputLimit(),
            thresholdType: typeThreshold,
            threshold: valueThreshold,
            delta: this.delta(),
            cropImageA: rectToCrop,
            cropImageB: rectToCrop,
            blockOut: this._blockOutAreas,
            verbose: this._args.verbose,
        });
        const result = this.runDiff(diff, output);
        this._blockOutAreas = undefined;
        return result;
    }
}
exports.ImageHelper = ImageHelper;
//# sourceMappingURL=image-helper.js.map